@@ -12,12 +12,16 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+import sys
+from urllib2 import URLError
 
 from lava_test.api.core import ITestProvider
 from lava_test.core.config import get_config
 from lava_test.core.tests import DeclarativeTest
 from lava_test.utils import Cache
 
+import logging
+
 
 class BuiltInProvider(ITestProvider):
     """
@@ -33,6 +37,7 @@ class BuiltInProvider(ITestProvider):
         'gtkperf',
         'ltp',
         'peacekeeper',
+        'perf',
         'posixtestsuite',
         'pwrmgmt',
         'pybench',
@@ -129,17 +134,22 @@ class RegistryProvider(ITestProvider):
 
     @classmethod
     def unregister_remote_test(self, test_url):
-      config = get_config()  # This is a different config object from
+        config = get_config()  # This is a different config object from
                              # self._config
-      provider_config = config.get_provider_config(
-          "lava_test.core.providers:RegistryProvider")
-      if "entries" not in provider_config:
-          provider_config["entries"] = []
-      if test_url in provider_config["entries"]:
-          provider_config["entries"].remove(test_url)
-          config._save_registry()
-      else:
-          raise ValueError("This test is not registered")
+        provider_config = config.get_provider_config("lava_test.core.providers:RegistryProvider")
+
+        if "entries" not in provider_config:
+            provider_config["entries"] = []
+
+        logging.info("removing remote test : " + test_url)
+        for entry in provider_config["entries"]:
+          logging.debug("found entry = " + str(entry))
+
+        if test_url in provider_config["entries"]:
+            provider_config["found remote test : "].remove(test_url)
+            config._save_registry()
+        else:
+            raise ValueError("This test is not registered")
 
     def _load_remote_test(self, test_url):
         """
@@ -162,8 +172,19 @@ class RegistryProvider(ITestProvider):
                 if test.test_id in self._cache:
                     raise ValueError("Duplicate test %s declared" % test.test_id)
                 self._cache[test.test_id] = test
-            except:
-                print("Warning: Failed to load test from '%s'" % test_url)
+            except IOError, err:
+                logging.warning("Failed to load the " + test_url)
+                if hasattr(e, 'reason'):
+                    logging.warning("WARNING: URL Reason: "+ e.reason)
+                elif hasattr(e, 'code'):
+                    logging.warning('WARNING: URL Error code: ' + e.code)
+                else:
+                    logging.exception("WARNING: Unknown IO error", str(err))
+            except ValueError, err:
+                logging.warning('Error found when parsing the' + test_url)
+            except Exception, err:
+                logging.warning('Failed to load the' + test_url)
+                logging.warning("Unknown exception : " + str(err))
 
     def __iter__(self):
         self._fill_cache()
