@@ -13,6 +13,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+Bootchart is a benchmark for measuring the time it takes to boot the system 
+to a point where it hands over control to the user.
+
+**URL:** http://bootchart.org
+
+**Default options:** None
+"""
+
+
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
