@@ -13,6 +13,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+The firefox benchmark measure the startup time for the firefox browser.
+
+**URL:** https://github.com/janimo/firefox-startup-timing
+
+**Default Options:** None
+"""
 
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
