@@ -14,10 +14,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-   This script automates the automate installation, execution, and
-   results parsing for the Peacekeeper browser benchmark.
+This script automates the automate installation, execution, and
+results parsing for the Peacekeeper browser benchmark.
 
-   http://clients.futuremark.com/peacekeeper/index.action
+**URL:** http://clients.futuremark.com/peacekeeper/index.action
+
+**Default options:** firefox
 """
 
 
