@@ -24,7 +24,7 @@ DEFAULT_OPTIONS = ""
 INSTALLSTEPS = ['git clone git://git.linaro.org/tools/pm-qa.git',
                 'cd pm-qa && make clean && make all']
 RUNSTEPS = ['cd pm-qa && make check $(OPTIONS)']
-DEPS = ['git-core', 'make', 'linux-libc-dev', 'util-linux']
+DEPS = ['git-core', 'make', 'linux-libc-dev', 'util-linux', 'build-essential']
 
 pwrmgmtinst = TestInstaller(INSTALLSTEPS, deps=DEPS)
 pwrmgmtrun = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
