@@ -13,6 +13,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+xrestop - test for X11 server resource usage monitor
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+Default options:
+ None
+"""
+
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
